@@ -195,7 +195,6 @@ class Client(metaclass=_Singleton):
             self._spotify_client_secret = None
             self._spotify_auth = None
             self._shutting_down = False
-            self.enable_managed_node = None
             self._scheduler = AsyncIOScheduler()
             self._scheduler.configure(timezone=utc)
         except Exception:
@@ -308,7 +307,12 @@ class Client(metaclass=_Singleton):
                     if not self._initiated:
                         self._initiated = True
                         self.ready.clear()
-                        await self.bot.wait_until_ready()
+                        if hasattr(self.bot, "wait_until_red_ready"):
+                            LOGGER.info("Running on a Red bot, waiting for Red to be ready")
+                            await self.bot.wait_until_red_ready()
+                        else:
+                            LOGGER.info("Running a discord.py bot waiting for bot to be ready")
+                            await self.bot.wait_until_ready()
                         await tables.DB.start_connection_pool(max_size=100)
                         if hasattr(self.bot, "get_shared_api_tokens") and callable(
                             getattr(self.bot, "get_shared_api_tokens")
@@ -335,13 +339,10 @@ class Client(metaclass=_Singleton):
                         java_path = config_data["java_path"]
                         config_folder = config_data["config_folder"]
                         localtrack_folder = config_data["localtrack_folder"]
-                        auto_update_managed_nodes = config_data["auto_update_managed_nodes"]
-                        enable_managed_node = config_data["enable_managed_node"]
                         if java_path != JAVA_EXECUTABLE and os.path.exists(JAVA_EXECUTABLE):
                             await self._config.update_java_path(JAVA_EXECUTABLE)
                         LOGGER.info("Config folder: %s", config_folder)
                         LOGGER.info("Localtracks folder: %s", localtrack_folder)
-                        self.enable_managed_node = enable_managed_node
                         self._config_folder = aiopath.AsyncPath(config_folder)
                         localtrack_folder = aiopath.AsyncPath(localtrack_folder)
                         bundled_node_config = self._node_config_manager.bundled_node_config()
@@ -370,14 +371,16 @@ class Client(metaclass=_Singleton):
 
                         await LocalFile.add_root_folder(path=localtrack_folder, create=True)
                         self._user_id = str(self._bot.user.id)
-                        self._local_node_manager = LocalNodeManager(self, auto_update=auto_update_managed_nodes)
+                        self._local_node_manager = LocalNodeManager(self)
+
+                        enable_managed_node = await self.lib_db_manager.get_config().fetch_enable_managed_node()
 
                         if (
                             not (
                                 self._node_manager._unmanaged_external_password
                                 and self._node_manager._unmanaged_external_host
                             )
-                            and self.enable_managed_node
+                            and enable_managed_node
                         ):
                             await self._local_node_manager.start(java_path=java_path)
                         else:
@@ -389,7 +392,7 @@ class Client(metaclass=_Singleton):
                                 self._node_manager._unmanaged_external_password
                                 and self._node_manager._unmanaged_external_host
                             )
-                            and self.enable_managed_node
+                            and enable_managed_node
                         ):
                             await self._local_node_manager.wait_until_connected()
                         time_now = datetime.datetime.now(tz=datetime.timezone.utc)
@@ -531,6 +534,7 @@ class Client(metaclass=_Singleton):
         yaml: dict | None = None,
         disabled_sources: list[str] = None,
         extras: dict = None,
+        temporary: bool = False,
     ) -> Node:
         """
         Adds a node to Lavalink's node manager.
@@ -568,6 +572,8 @@ class Client(metaclass=_Singleton):
             Whether the node is managed by the client. Defaults to `False`.
         disabled_sources: Optional[:class:`list`[:class:`str`]]
             A list of sources that should be disabled for the node. Defaults to `None`.
+        temporary: :class:`bool`
+            Whether the node is temporary. Defaults to `False`.
         """
         return await self.node_manager.add_node(
             host=host,
@@ -584,6 +590,7 @@ class Client(metaclass=_Singleton):
             yaml=yaml,
             disabled_sources=disabled_sources,
             extras=extras or {},
+            temporary=temporary,
         )
 
     async def decode_track(self, track: str, feature: str = None) -> dict | None:
@@ -883,6 +890,12 @@ class Client(metaclass=_Singleton):
 
         return random.choice(available_nodes) if available_nodes else None
 
+    async def get_my_node(self) -> Node | None:
+        return await asyncstdlib.anext(
+            asyncstdlib.filter(lambda n: n.identifier == self.bot.user.id, self.node_manager.managed_nodes),
+            default=None,
+        )
+
     async def _get_tracks(
         self,
         query: Query,
