@@ -164,8 +164,7 @@ class LocalNodeManager:
     _version: str | None = None
     _java_exc: str = JAVA_EXECUTABLE
 
-    def __init__(self, client: Client, timeout: int | None = None, auto_update: bool = True) -> None:
-        self._auto_update = False if USING_FORCED else auto_update
+    def __init__(self, client: Client, timeout: int | None = None) -> None:
         self.ready: asyncio.Event = asyncio.Event()
         self._ci_info: dict = {"number": 0, "branchName": "", "finishDate": "", "href": "", "jar_url": ""}
         self._client = client
@@ -461,8 +460,15 @@ class LocalNodeManager:
             await self._client.remove_node(self._node_id)
             self._node = None
 
+    async def should_auto_update(self) -> bool:
+        return (
+            False
+            if USING_FORCED
+            else await self._client._lib_config_manager.get_config().fetch_auto_update_managed_nodes()
+        )
+
     async def _download_jar(self) -> None:
-        if not self._auto_update:
+        if not await self.should_auto_update():
             return
         LOGGER.info("Downloading Lavalink.jar")
         jar_url = (
@@ -546,7 +552,7 @@ class LocalNodeManager:
         self._commit = commit["commit"].decode()
         self._version = version["version"].decode()
         self._buildtime = date
-        if self._auto_update:
+        if await self.should_auto_update():
             self._up_to_date = last_download_id == self._ci_info.get("number", -1)
         else:
             self._ci_info["number"] = build
@@ -745,15 +751,24 @@ class LocalNodeManager:
                 return
         if (node := self._client.node_manager.get_node_by_id(self._node_id)) is None:
             data = await self._client.node_db_manager.bundled_node_config().fetch_all()
+            resume_key = (
+                f"PyLav/{self._client.lib_version}/PyLavPortConflictRecovery-{self._client.bot.user.id}-{self._node_pid}"
+                if external_fallback
+                else f"PyLav/{self._client.lib_version}/PyLavManagedNode-{self._client.bot.user.id}-{self._node_pid}"
+            )
+            name = (
+                f"PyLavPortConflictRecovery: {self._node_pid}"
+                if external_fallback
+                else f"PyLavManagedNode: {self._node_pid}"
+            )
+            data["yaml"]["sentry"]["tags"]["pylav_version"] = self._client.lib_version
             node = self._node = await self._client.add_node(
                 host=self._current_config["server"]["address"],
                 port=self._current_config["server"]["port"],
                 password=self._current_config["lavalink"]["server"]["password"],
-                resume_key=f"ManagedNode-{self._node_pid}-{self._node_id}",
+                resume_key=resume_key,
                 resume_timeout=data["resume_timeout"],
-                name=f"PyLavPortConflictRecovery: {self._node_pid}"
-                if external_fallback
-                else f"{data['name'].split(':')[0]}: {self._node_pid}",
+                name=name,
                 yaml=data["yaml"],
                 extras=data["extras"],
                 managed=True,
@@ -761,7 +776,8 @@ class LocalNodeManager:
                 search_only=False,
                 unique_identifier=self._client.node_db_manager.bundled_node_config().id,
             )
-
+            await node.config.update_name(name)
+            await node.config.update_resume_key(resume_key)
         else:
             self._node = node
         if node.websocket.connecting:
@@ -772,7 +788,7 @@ class LocalNodeManager:
             LOGGER.info("Managed Lavalink node is not connected, reconnecting")
             await node.websocket.close()
             await node.websocket._websocket_closed(reason="Managed Node restart")
-            await node.wait_until_ready(timeout=30)
+            await node.wait_until_ready(timeout=60)
         self._wait_for.set()
 
     @staticmethod
@@ -799,5 +815,10 @@ class LocalNodeManager:
 
     async def restart(self, java_path: str = None):
         LOGGER.info("Restarting managed Lavalink node")
+        node = await self._client.get_my_node()
+        if node:
+            await node.websocket.manual_closure(managed_node=True)
+            with contextlib.suppress(Exception):
+                await node.close()
         await self.shutdown()
         await self.start(java_path=java_path or self._java_path)
