@@ -1,6 +1,10 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
+import datetime
+import functools
+import pathlib
 import typing
 from typing import TYPE_CHECKING, Any
 from uuid import uuid4
@@ -8,6 +12,8 @@ from uuid import uuid4
 import aiohttp
 import asyncstdlib
 import ujson
+from apscheduler.jobstores.base import JobLookupError
+from expiringdict import ExpiringDict
 
 from pylav._logging import getLogger
 from pylav.constants import BUNDLED_NODES_IDS, PYLAV_NODES, REGION_TO_COUNTRY_COORDINATE_MAPPING, SUPPORTED_SOURCES
@@ -27,7 +33,7 @@ from pylav.filters import (
 )
 from pylav.filters.tremolo import Tremolo
 from pylav.location import distance
-from pylav.sql.models import NodeModel
+from pylav.sql.models import NodeModel, NodeModelMock
 from pylav.types import LavalinkResponseT, TrackT
 from pylav.utils import AsyncIter
 
@@ -37,6 +43,13 @@ if TYPE_CHECKING:
     from pylav.query import Query
     from pylav.websocket import WebSocket
 
+try:
+    from redbot.core.i18n import Translator
+
+    _ = Translator("PyLavPlayer", pathlib.Path(__file__))
+except ImportError:
+    _ = lambda x: x
+
 
 LOGGER = getLogger("PyLav.Node")
 
@@ -84,7 +97,13 @@ class Penalty:
 
         This is the sum of the penalties of the node.
         """
-        return self.player_penalty + self.cpu_penalty + self.null_frame_penalty + self.deficit_frame_penalty
+        return (
+            self.player_penalty
+            + self.cpu_penalty
+            + self.null_frame_penalty
+            + self.deficit_frame_penalty
+            + self._stats._node.down_votes * 100
+        )
 
 
 class Stats:
@@ -120,12 +139,12 @@ class Stats:
     @property
     def players(self) -> int:
         """The amount of players connected to the node"""
-        return self._data["players"]
+        return self._data["players"] or self._node.connected_count
 
     @property
     def playing_players(self) -> int:
         """The amount of players that are playing in the node"""
-        return self._data["playingPlayers"]
+        return self._data["playingPlayers"] or self._node.playing_count
 
     @property
     def memory_free(self) -> int:
@@ -227,13 +246,18 @@ class Node:
         disabled_sources: list[str] = None,
         managed: bool = False,
         extras: dict = None,
+        temporary: bool = False,
     ):
         from pylav.query import Query
 
         self._query_cls: Query = Query  # type: ignore
         self._manager = manager
         self._session = aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=30), json_serialize=ujson.dumps)
-        self._config: NodeModel = self._manager._client.node_db_manager.get_node_config(unique_identifier)
+        self._temporary = temporary
+        if not temporary:
+            self._config: NodeModel = self._manager._client.node_db_manager.get_node_config(unique_identifier)
+        else:
+            self._config: NodeModelMock = None
         if unique_identifier is None:
             unique_identifier = str(uuid4())
         self._managed = managed
@@ -259,6 +283,7 @@ class Node:
         self._search_only = search_only
         self._sources = self._capabilities = set()
         self._coordinates = (0, 0)
+        self._down_votes = ExpiringDict(max_len=float("inf"), max_age_seconds=600)  # type: ignore
 
         self._stats = None
         from pylav.websocket import WebSocket
@@ -274,10 +299,40 @@ class Node:
             reconnect_attempts=self.reconnect_attempts,
             ssl=self.ssl,
         )
+        self._manager.client.scheduler.add_job(
+            self.node_monitor_task,
+            trigger="interval",
+            seconds=5,
+            max_instances=1,
+            id=f"{self.identifier}-{self._manager.client.bot.user.id}-node_monitor_task",
+            replace_existing=True,
+            coalesce=True,
+            next_run_time=datetime.datetime.now(tz=datetime.timezone.utc) + datetime.timedelta(seconds=15),
+        )
+
+    async def node_monitor_task(self):
+        with contextlib.suppress(
+            asyncio.exceptions.CancelledError,
+        ):
+            playing_players = len(self.playing_players)
+            if playing_players == 0:
+                return
+            if (self.down_votes / playing_players) >= 0.5:
+                del self.down_votes
+
+                if self._ws is not None:
+                    await self.websocket.manual_closure(
+                        managed_node=self.identifier == self.node_manager.client.bot.user.id
+                        and self.websocket is not None
+                    )
+                if self.identifier == self.node_manager.client.bot.user.id:
+                    await self.node_manager.client.managed_node_controller.restart()
+                    with contextlib.suppress(Exception):
+                        await self.close()
 
     @property
     def is_ready(self) -> bool:
-        return self._ready.is_set() and self._ws.connected
+        return self._ready.is_set() and self.websocket.connected
 
     @property
     def coordinates(self) -> tuple[int, int]:
@@ -295,7 +350,7 @@ class Node:
         return self._managed
 
     @property
-    def config(self) -> NodeModel:
+    def config(self) -> NodeModelMock | NodeModel:
         return self._config
 
     @property
@@ -412,12 +467,12 @@ class Node:
     @property
     def server_connected_players(self) -> int:
         """Returns the number of players on this node that are connected"""
-        return self.stats.players if self.stats else len(self.connected_players)
+        return self.stats.players if self.stats else self.connected_count
 
     @property
     def server_playing_players(self) -> int:
         """Returns the number of players on this node that are playing"""
-        return self.stats.playing_players if self.stats else len(self.playing_players)
+        return self.stats.playing_players if self.stats else self.playing_count
 
     @property
     def count(self) -> int:
@@ -441,6 +496,34 @@ class Node:
             return float("inf")
         return self.stats.penalty.total
 
+    def down_vote(self, player: Player) -> int:
+        """Adds a down vote for this node"""
+        if not player.is_playing:
+            return -1
+        self._down_votes[player.guild.id] = 1
+        return self.down_votes
+
+    def down_unvote(self, player: Player) -> int:
+        """Removes a down vote for this node"""
+        if not player.is_playing:
+            return -1
+        self._down_votes.pop(player.guild.id, None)
+        return self.down_votes
+
+    @property
+    def down_votes(self) -> int:
+        """Returns the down votes for this node"""
+        return len(set(self._down_votes.keys()))
+
+    def voted(self, player: Player) -> bool:
+        """Returns whether a player has voted for this node"""
+        return player.guild.id in self._down_votes
+
+    @down_votes.deleter
+    def down_votes(self):
+        """Clears the down votes for this node"""
+        self._down_votes.clear()
+
     async def penalty_with_region(self, region: str | None) -> float:
         """The penalty for the node, with the region added in"""
         if not region:
@@ -470,12 +553,23 @@ class Node:
     def __repr__(self):
         return (
             f"<Node id={self.identifier} name={self.name} "
-            f"region={self.region} ssl={self.ssl} search_only={self.search_only} status={self._ws.connected}>"
+            f"region={self.region} ssl={self.ssl} "
+            f"search_only={self.search_only} connected={self.websocket.connected if self._ws else False} "
+            f"votes={self.down_votes} "
+            f"players={self.server_connected_players} playing={self.server_playing_players}>"
         )
 
     def __eq__(self, other):
         if isinstance(other, Node):
-            return self.identifier == other.identifier
+            return functools.reduce(
+                lambda x, y: x and y,
+                map(
+                    lambda p, q: p == q,
+                    [self.identifier, self.websocket.connected, self.name, self._resume_key],
+                    [other.identifier, self.websocket.connected, self.name, self._resume_key],
+                ),
+                True,
+            )
         elif isinstance(other, NodeModel):
             return self.identifier == other.id
         return NotImplemented
@@ -878,8 +972,7 @@ class Node:
         await self.send(**op)
 
     async def get_unsupported_features(self) -> set[str]:
-        if not self._capabilities:
-            await self.update_features()
+        await self.update_features()
         return SUPPORTED_SOURCES - self._capabilities
 
     async def update_features(self):
@@ -1249,9 +1342,13 @@ class Node:
         """
         Closes the target node.
         """
-        if self._ws is not None:
-            await self._ws.close()
+        if self.websocket is not None:
+            await self.websocket.close()
         await self.session.close()
+        with contextlib.suppress(JobLookupError):
+            self.node_manager.client.scheduler.remove_job(
+                job_id=f"{self.identifier}-{self._manager.client.bot.user.id}-node_monitor_task"
+            )
 
     async def wait_until_ready(self, timeout: float | None = None):
         await asyncio.wait_for(self._ready.wait(), timeout=timeout)
