@@ -10,6 +10,7 @@ from typing import TYPE_CHECKING
 import aiohttp
 import asyncstdlib
 import ujson
+from discord.backoff import ExponentialBackoff
 
 from pylav._logging import getLogger
 from pylav.constants import (
@@ -23,7 +24,7 @@ from pylav.events import NodeConnectedEvent, NodeDisconnectedEvent
 from pylav.location import get_closest_region_name_and_coordinate
 from pylav.node import Node
 from pylav.player import Player
-from pylav.sql.models import LibConfigModel
+from pylav.sql.models import LibConfigModel, NodeModelMock
 from pylav.utils import sort_key_nodes
 
 if TYPE_CHECKING:
@@ -115,6 +116,7 @@ class NodeManager:
         managed: bool = False,
         yaml: dict | None = None,
         extras: dict = None,
+        temporary: bool = False,
     ) -> Node:
         """
         Adds a node to PyLav's node manager.
@@ -152,6 +154,9 @@ class NodeManager:
             A dictionary of node settings. Defaults to `None`.
         extras: Optional[:class:`dict`]
             A dictionary of extra settings. Defaults to `{}`.
+        temporary: :class:`bool`
+            Whether the node is temporary. Defaults to `False`.
+            Temporary nodes are not added to the db.
 
         Returns
         -------
@@ -173,27 +178,49 @@ class NodeManager:
             disabled_sources=disabled_sources,
             managed=managed,
             extras=extras or {},
+            temporary=temporary,
         )
         self._nodes.append(node)
 
         LOGGER.info("[NODE-%s] Successfully added to Node Manager", node.name)
         LOGGER.verbose("[NODE-%s] Successfully added to Node Manager -- %r", node.name, node)
-        node._config = await self.client.node_db_manager.update_node(
-            host=host,
-            port=port,
-            password=password,
-            resume_key=resume_key,
-            resume_timeout=resume_timeout,
-            name=name,
-            reconnect_attempts=reconnect_attempts,
-            ssl=ssl,
-            search_only=search_only,
-            unique_identifier=unique_identifier,
-            disabled_sources=disabled_sources,
-            managed=managed,
-            yaml=yaml,
-            extras=extras or {},
-        )
+
+        if temporary:
+            yaml = yaml or {"server": {}, "lavalink": {"server": {}}}
+            yaml["server"]["address"] = host  # type: ignore
+            yaml["server"]["port"] = port  # type: ignore
+            yaml["lavalink"]["server"]["password"] = password
+            data = {
+                "name": name,
+                "ssl": ssl,
+                "resume_key": resume_key,
+                "resume_timeout": resume_timeout,
+                "reconnect_attempts": reconnect_attempts,
+                "search_only": search_only,
+                "managed": managed,
+                "extras": extras or {},
+                "yaml": yaml,
+                "disabled_sources": disabled_sources,
+            }
+            node._config = NodeModelMock(id=unique_identifier, data=data)
+
+        else:
+            node._config = await self.client.node_db_manager.update_node(
+                host=host,
+                port=port,
+                password=password,
+                resume_key=resume_key,
+                resume_timeout=resume_timeout,
+                name=name,
+                reconnect_attempts=reconnect_attempts,
+                ssl=ssl,
+                search_only=search_only,
+                unique_identifier=unique_identifier,
+                disabled_sources=disabled_sources,
+                managed=managed,
+                yaml=yaml,
+                extras=extras or {},
+            )
         return node
 
     async def remove_node(self, node: Node) -> None:
@@ -258,6 +285,9 @@ class NodeManager:
         feature: str = None,
         already_attempted_regions: set[str] = None,
         coordinates: tuple[float, float] = None,
+        wait: bool = False,
+        attempt: int = 0,
+        backoff: ExponentialBackoff = None,
     ) -> Node | None:
         """Finds the best (least used) node in the given region, if applicable.
         Parameters
@@ -272,10 +302,21 @@ class NodeManager:
             A set of regions that have already been attempted.
         coordinates: :class:`tuple`[:class:`float`, :class:`float`]
             The coordinates to use.
+        wait: :class:`bool`
+            Whether to wait for a node to become available.
+        attempt: :class:`int`
+            The current attempt number.
+        backoff: :class:`ExponentialBackoff`
+            The backoff to use.
         Returns
         -------
         Optional[:class:`Node`]
         """
+        if backoff is None:
+            backoff = ExponentialBackoff()
+            delay = 1
+        else:
+            delay = backoff.delay()
         already_attempted_regions = already_attempted_regions or set()
         if feature:
             nodes = [n for n in self.available_nodes if n.has_capability(feature)]
@@ -318,7 +359,20 @@ class NodeManager:
                 ]
             else:
                 nodes = self.available_nodes
-        return await asyncstdlib.min(nodes, key=partial(sort_key_nodes, region=region), default=None) if nodes else None
+        node = await asyncstdlib.min(nodes, key=partial(sort_key_nodes, region=region), default=None) if nodes else None
+        if node is None and wait:
+            await asyncio.sleep(delay)
+            return await self.find_best_node(
+                region=region,
+                not_region=not_region,
+                feature=feature,
+                already_attempted_regions=already_attempted_regions,
+                coordinates=coordinates,
+                wait=wait,
+                backoff=backoff,
+                attempt=attempt + 1,
+            )
+        return node
 
     def get_node_by_id(self, unique_identifier: int) -> Node | None:
         """
@@ -342,6 +396,7 @@ class NodeManager:
             The node that has just connected.
         """
         LOGGER.info("[NODE-%s] Successfully established connection", node.name)
+        del node.down_votes
 
         async for player in asyncstdlib.iter(self.player_queue):
             await player.change_node(node)
@@ -437,6 +492,7 @@ class NodeManager:
                         "unique_identifier": 31415,
                         "name": "ENVAR Node (Unmanaged)",
                         "resume_key": f"PyLav/{self.client.lib_version}-{self.client.bot_id}",
+                        "temporary": True,
                     }
                 nodes_list.append(await self.add_node(**base_settings))
             else:
@@ -496,7 +552,7 @@ class NodeManager:
         if not tasks:
             if (
                 not (self._unmanaged_external_password and self._unmanaged_external_host)
-                and self.client.enable_managed_node
+                and await self.client.lib_db_manager.get_config().fetch_enable_managed_node()
             ):
                 self._adding_nodes.set()
                 return
