@@ -83,6 +83,13 @@ LOGGER = getLogger("PyLav.Player")
 ENDPONT_REGEX = re.compile(r"^(?P<region>.*?)\d+.discord.media:\d+$")
 
 
+def _done_callback(task: asyncio.Task) -> None:
+    with contextlib.suppress(asyncio.CancelledError):
+        exc = task.exception()
+        if exc is not None:
+            LOGGER.error("Error in task %s", task.get_name(), exc_info=exc)
+
+
 class Player(VoiceProtocol):
     _config: PlayerModel
     _global_config: PlayerModel
@@ -95,6 +102,7 @@ class Player(VoiceProtocol):
         *,
         node: Node = None,
     ):
+        self.ready = asyncio.Event()
         self.bot = self.client = client
         self.guild_id = str(channel.guild.id)
         self._channel = None
@@ -125,7 +133,6 @@ class Player(VoiceProtocol):
         self.history: TrackHistoryQueue[Track] = TrackHistoryQueue(maxsize=100)
         self.current: Track | None = None
         self._post_init_completed = False
-        self._queue_length = 0
         self._autoplay_playlist: PlaylistModel = None  # type: ignore
         self._restored = False
 
@@ -147,11 +154,20 @@ class Player(VoiceProtocol):
         self._extras = {}
 
         self._last_alone_paused_check = 0
+        self._was_alone_paused = False
         self._last_alone_dc_check = 0
         self._last_empty_queue_check = 0
 
-    def __str__(self):
-        return f"Player(id={self.guild.id}, channel={self.channel.id})"
+        self._waiting_for_node = asyncio.Event()
+
+    def __repr__(self):
+        return (
+            f"<Player id={self.guild.id} "
+            f"channel={self.channel.id} "
+            f"playing={self.is_playing} "
+            f"queue={self.queue.size()} "
+            f"node={self.node}>"
+        )
 
     async def post_init(
         self,
@@ -245,6 +261,7 @@ class Player(VoiceProtocol):
             coalesce=True,
             next_run_time=now_time + datetime.timedelta(seconds=3),
         )
+
         self.player_manager.client.scheduler.add_job(
             self.auto_empty_queue_task,
             trigger="interval",
@@ -265,6 +282,17 @@ class Player(VoiceProtocol):
             coalesce=True,
             next_run_time=now_time + datetime.timedelta(seconds=1),
         )
+        self.player_manager.client.scheduler.add_job(
+            self.auto_resume_task,
+            trigger="interval",
+            seconds=5,
+            max_instances=1,
+            id=f"{self.bot.user.id}-{self.guild.id}-auto_resume_task",
+            replace_existing=True,
+            coalesce=True,
+            next_run_time=now_time + datetime.timedelta(seconds=4),
+        )
+
         self.player_manager.client.scheduler.add_job(
             self.auto_save_task,
             trigger="interval",
@@ -275,6 +303,7 @@ class Player(VoiceProtocol):
             coalesce=True,
             next_run_time=now_time + datetime.timedelta(seconds=10),
         )
+        self.ready.set()
 
     @property
     def channel(self) -> discord.channel.VocalGuildChannel:
@@ -311,6 +340,15 @@ class Player(VoiceProtocol):
     def radio(self) -> RadioBrowser:
         return self.lavalink.radio_browser
 
+    def vote_node_down(self) -> int:
+        return -1 if (self.node is None or not self.is_playing) else self.node.down_vote(self)
+
+    def voted(self) -> bool:
+        return self.node.voted(self)
+
+    def unvote_node_down(self) -> int:
+        return -1 if (self.node is None or not self.is_playing) else not self.node.down_unvote(self)
+
     async def text_channel(self) -> discord.abc.MessageableChannel:
         return self.guild.get_channel_or_thread(await self.config.fetch_text_channel_id())
 
@@ -450,6 +488,8 @@ class Player(VoiceProtocol):
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
+            if not self.ready.is_set():
+                return
             if not self.is_connected:
                 LOGGER.trace(
                     "Auto Pause task for %s fired while player is not connected to a voice channel - discarding",
@@ -478,14 +518,46 @@ class Player(VoiceProtocol):
                         feature.time,
                     )
                     await self.set_pause(pause=True, requester=self.guild.me)
+                    self._was_alone_paused = True
                     self._last_alone_paused_check = 0
             else:
                 self._last_alone_paused_check = 0
 
+    async def auto_resume_task(self):
+        with contextlib.suppress(
+            asyncio.exceptions.CancelledError,
+        ):
+            if not self.ready.is_set():
+                return
+            if not self._was_alone_paused:
+                LOGGER.trace(
+                    "Auto Resume task for %s fired while player is auto paused - discarding",
+                    self,
+                )
+                return
+            if (
+                self.paused
+                and not self.is_empty
+                and (
+                    feature := await self.player_manager.client.player_config_manager.get_alone_pause(
+                        guild_id=self.guild.id
+                    )
+                ).enabled
+            ):
+                LOGGER.info(
+                    "Auto Resume task for %s - Player in an non-empty channel - Resuming",
+                    self,
+                    feature.time,
+                )
+                await self.set_pause(pause=False, requester=self.guild.me)
+                self._was_alone_paused = False
+
     async def auto_dc_task(self):
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
+            if not self.ready.is_set():
+                return
             if not self.is_connected:
                 LOGGER.trace(
                     "Auto Disconnect task for %s fired while player is not connected to a voice channel - discarding",
@@ -522,6 +594,8 @@ class Player(VoiceProtocol):
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
+            if not self.ready.is_set():
+                return
             if not self.is_connected:
                 LOGGER.trace(
                     "Auto Empty Queue task for %s fired while player is not connected to a voice channel - discarding",
@@ -574,46 +648,60 @@ class Player(VoiceProtocol):
                     self,
                 )
                 return
-            LOGGER.verbose(
+            LOGGER.trace(
                 "Auto save task for %s - Saving the player at %s", self, datetime.datetime.now(tz=datetime.timezone.utc)
             )
             await self.save()
 
-    async def change_to_best_node(self, feature: str = None) -> Node | None:
+    async def change_to_best_node(self, feature: str = None, ops: bool = True) -> Node | None:
         """
         Returns the best node to play the current track.
         Returns
         -------
         :class:`Node`
         """
+        if feature is None and self.current:
+            feature = await self.current.requires_capability()
         node = await self.node.node_manager.find_best_node(
             region=self.region, feature=feature, coordinates=self.coordinates
         )
-        if feature and not node:
-            raise NoNodeWithRequestFunctionalityAvailable(
-                _("No node with {feature} functionality available!").format(feature=feature), feature=feature
+        if not node:
+            LOGGER.warning("No node with %s functionality available - Waiting for one to become available!", feature)
+            node = await self.node.node_manager.find_best_node(
+                region=self.region, feature=feature, coordinates=self.coordinates, wait=True
             )
 
-        if node != self.node:
-            await self.change_node(node)
+        if feature and not node:
+            LOGGER.warning("No node with %s functionality available after one temporarily became available!", feature)
+            raise NoNodeWithRequestFunctionalityAvailable(f"No node with {feature} functionality available", feature)
+        if node != self.node or not ops:
+            await self.change_node(node, ops=ops)
             return node
 
-    async def change_to_best_node_diff_region(self, feature: str = None) -> Node | None:
+    async def change_to_best_node_diff_region(self, feature: str = None, ops: bool = True) -> Node | None:
         """
         Returns the best node to play the current track in a different region.
         Returns
         -------
         :class:`Node`
         """
+        if feature is None and self.current:
+            feature = await self.current.requires_capability()
         node = await self.node.node_manager.find_best_node(
             not_region=self.region, feature=feature, coordinates=self.coordinates
         )
-        if feature and not node:
-            raise NoNodeWithRequestFunctionalityAvailable(
-                _("No node with {feature} functionality available!").format(feature=feature), feature=feature
+        if not node:
+            LOGGER.warning("No node with %s functionality available - Waiting for one to become available!", feature)
+            node = await self.node.node_manager.find_best_node(
+                region=self.region, feature=feature, coordinates=self.coordinates, wait=True
             )
-        if node != self.node:
-            await self.change_node(node)
+
+        if feature and not node:
+            LOGGER.warning("No node with %s functionality available after one temporarily became available!", feature)
+            raise NoNodeWithRequestFunctionalityAvailable(f"No node with {feature} functionality available", feature)
+
+        if node != self.node or not ops:
+            await self.change_node(node, ops=ops)
             return node
 
     def store(
@@ -1082,6 +1170,7 @@ class Player(VoiceProtocol):
         await self.node.send(op="pause", guildId=self.guild_id, pause=pause)
 
         self.paused = pause
+        self._was_alone_paused = False
         if self.paused:
             self.node.dispatch_event(PlayerPausedEvent(self, requester))
         else:
@@ -1168,25 +1257,24 @@ class Player(VoiceProtocol):
         event = PlayerUpdateEvent(self, self._last_position, self.position_timestamp)
         self.node.dispatch_event(event)
 
-    async def change_node(self, node: Node) -> None:
+    async def change_node(self, node: Node, ops: bool = True) -> None:
         """
         Changes the player's node
         Parameters
         ----------
         node: :class:`Node`
             The node the player is changed to.
+        ops: :class:`bool`
+            Whether to change apply the volume and filter ops on change.
         """
-        if node.identifier == self.node.identifier:
+        if node == self.node and self.node.available and ops:
             return
         if self.node.available:
             await self.node.send(op="destroy", guildId=self.guild_id)
-
         old_node = self.node
         self.node = node
-
         if self._voice_state:
             await self._dispatch_voice_update()
-
         if self.current:
             options = {}
             if self.current.skip_segments and self.node.supports_sponsorblock:
@@ -1195,27 +1283,27 @@ class Player(VoiceProtocol):
                 op="play", guildId=self.guild_id, track=self.current.track, startTime=self.position, **options
             )
             self._last_update = time.time() * 1000
-
             if self.paused:
                 await self.node.send(op="pause", guildId=self.guild_id, pause=self.paused)
-        if self.has_effects:
-            await self.set_filters(
-                requester=self.guild.me,
-                equalizer=self.equalizer,
-                karaoke=self.karaoke,
-                timescale=self.timescale,
-                tremolo=self.tremolo,
-                vibrato=self.vibrato,
-                rotation=self.rotation,
-                distortion=self.distortion,
-                low_pass=self.low_pass,
-                channel_mix=self.channel_mix,
-                echo=self.echo,
-                reset_not_set=True,
-            )
-        if self.volume_filter.changed:
-            await self.node.send(op="volume", guildId=self.guild_id, volume=self.volume)
+        if ops:
+            if self.has_effects:
+                await self.set_filters(
+                    requester=self.guild.me,
+                    equalizer=self.equalizer,
+                    karaoke=self.karaoke,
+                    timescale=self.timescale,
+                    tremolo=self.tremolo,
+                    vibrato=self.vibrato,
+                    rotation=self.rotation,
+                    distortion=self.distortion,
+                    low_pass=self.low_pass,
+                    channel_mix=self.channel_mix,
+                    echo=self.echo,
+                    reset_not_set=True,
+                )
 
+            if self.volume_filter.changed:
+                await self.node.send(op="volume", guildId=self.guild_id, volume=self.volume)
         self.node.dispatch_event(NodeChangedEvent(self, old_node, node))
 
     async def connect(
@@ -2049,6 +2137,7 @@ class Player(VoiceProtocol):
             "extras": {
                 "last_track": await self.last_track.to_json() if self.last_track else None,
                 "next_track": await self.next_track.to_json() if self.next_track else None,
+                "was_alone_paused": self._was_alone_paused,
             },
         }
 
@@ -2059,6 +2148,7 @@ class Player(VoiceProtocol):
         # sourcery no-metrics
         if self._restored is True:
             return
+        self._was_alone_paused = player.extras.get("was_alone_paused", False)
         current = (
             Track(
                 node=self.node,
@@ -2135,25 +2225,6 @@ class Player(VoiceProtocol):
         self.queue.raw_b64s = [t.track for t in queue if t.track]
         self.history.raw_queue = collections.deque(history)
         self.history.raw_b64s = [t.track for t in history]
-        if current:
-            current.timestamp = int(player.position)
-            self.queue.put_nowait([current], index=0)
-            node = await self.node.node_manager.find_best_node(
-                region=self.region, feature=await current.requires_capability(), coordinates=self._coordinates
-            )
-            tried = 0
-            while not node:
-                await asyncio.sleep(1)
-                node = await self.node.node_manager.find_best_node(
-                    region=self.region, feature=await current.requires_capability(), coordinates=self._coordinates
-                )
-                tried += 1
-                if tried > 600:
-                    return  # Exit without restoring after 10 minutes of waiting
-            await self.change_node(node)
-        else:
-            await self.change_to_best_node()
-
         self._effect_enabled = player.effect_enabled
         effects = player.effects
         if (v := effects.get("volume", None)) and (f := Volume.from_dict(v)) and f.changed:
@@ -2178,7 +2249,10 @@ class Player(VoiceProtocol):
             self._channel_mix = f
         if (v := effects.get("echo", None)) and (f := Echo.from_dict(v)) and f.changed:
             self._echo = f
-
+        if current:
+            self.current = current
+            current.timestamp = int(player.position)
+        await self.change_to_best_node(ops=False)
         if self.has_effects:
             await self.node.filters(
                 guild_id=self.channel.guild.id,
@@ -2195,7 +2269,7 @@ class Player(VoiceProtocol):
             )
         if self.volume_filter.changed:
             await self.node.send(op="volume", guildId=self.guild_id, volume=self.volume)
-        if player.playing:
+        if player.playing and not current:
             await self.next(requester)  # type: ignore
         self.last_track = last_track
         self._restored = True
