@@ -5,6 +5,7 @@ from typing import TYPE_CHECKING
 
 from packaging.version import parse as parse_version
 
+from pylav.constants import BUNDLED_NODES_IDS
 from pylav.exceptions import EntryNotFoundError
 from pylav.utils.built_in_node import NODE_DEFAULT_SETTINGS
 
@@ -21,18 +22,18 @@ class UpdateSchemaManager:
         from pylav import __VERSION__
 
         current_version = await self._client.lib_db_manager.get_bot_db_version().fetch_version()
-        if current_version == parse_version("0.0.0.0"):
+        if current_version == parse_version("0.0.0.0.9999"):
             await self._client.lib_db_manager.update_bot_dv_version(__VERSION__)
             return
 
-        if current_version <= parse_version("0.0.0.1"):
+        if current_version <= parse_version("0.0.0.1.9999"):
             config = self._client.node_db_manager.bundled_node_config()
             yaml_data = await config.fetch_yaml()
             yaml_data["lavalink"]["server"]["trackStuckThresholdMs"] = 10000
             await config.update_yaml(yaml_data)
             await self._client.lib_db_manager.update_bot_dv_version("0.0.0.2")
 
-        if current_version <= parse_version("0.3.1"):
+        if current_version <= parse_version("0.3.1.9999"):
             config = self._client.node_db_manager.bundled_node_config()
             yaml_data = await config.fetch_yaml()
             yaml_data["lavalink"]["server"]["opusEncodingQuality"] = 10
@@ -41,14 +42,14 @@ class UpdateSchemaManager:
             await config.update_yaml(yaml_data)
             await self._client.lib_db_manager.update_bot_dv_version("0.3.2")
 
-        if current_version <= parse_version("0.3.2"):
+        if current_version <= parse_version("0.3.2.9999"):
             config = self._client.node_db_manager.bundled_node_config()
             yaml_data = await config.fetch_yaml()
             yaml_data["lavalink"]["server"]["youtubeConfig"] = {"email": "", "password": ""}
             await config.update_yaml(yaml_data)
             await self._client.lib_db_manager.update_bot_dv_version("0.3.3")
 
-        if current_version <= parse_version("0.3.3"):
+        if current_version <= parse_version("0.3.3.9999"):
             config = self._client.node_db_manager.bundled_node_config()
             yaml_data = await config.fetch_yaml()
             if "soundgasm" not in yaml_data["plugins"]["dunctebot"]["sources"]:
@@ -58,7 +59,7 @@ class UpdateSchemaManager:
             await config.update_yaml(yaml_data)
             await self._client.lib_db_manager.update_bot_dv_version("0.3.4")
 
-        if current_version <= parse_version("0.3.4"):
+        if current_version <= parse_version("0.3.4.9999"):
             config = self._client.node_db_manager.bundled_node_config()
             yaml_data = await config.fetch_yaml()
             if "path" in yaml_data["logging"]:
@@ -66,7 +67,7 @@ class UpdateSchemaManager:
                 await config.update_yaml(yaml_data)
             await self._client.lib_db_manager.update_bot_dv_version("0.3.5")
 
-        if current_version <= parse_version("0.3.5"):
+        if current_version <= parse_version("0.3.5.9999"):
             config = self._client.node_db_manager.bundled_node_config()
             yaml_data = await config.fetch_yaml()
             if "path" in yaml_data["logging"]:
@@ -86,19 +87,23 @@ class UpdateSchemaManager:
             await config.update_yaml(yaml_data)
             await self._client.lib_db_manager.update_bot_dv_version("0.3.6")
 
-        if current_version <= parse_version("0.7.5"):
+        if current_version <= parse_version("0.7.5.9999"):
             config = self._client.node_db_manager.bundled_node_config()
             yaml_data = await config.fetch_yaml()
             if len(yaml_data["lavalink"]["plugins"]) < len(NODE_DEFAULT_SETTINGS["lavalink"]["plugins"]):
                 yaml_data["lavalink"]["plugins"] = NODE_DEFAULT_SETTINGS["lavalink"]["plugins"]
                 await config.update_yaml(yaml_data)
 
-        if current_version <= parse_version("0.8.4"):
+        if current_version <= parse_version("0.8.4.9999"):
             playlists = [p for p in await self._client.playlist_db_manager.get_bundled_playlists() if p.id in {1, 2}]
             for playlist in playlists:
                 await playlist.delete()
             await self._client.playlist_db_manager.update_bundled_playlists(1, 2)
 
+        if current_version <= parse_version("0.8.7.9999"):
+            for node_id in BUNDLED_NODES_IDS:
+                await self._client.node_db_manager.delete(node_id)
+
         with contextlib.suppress(EntryNotFoundError):
             config = self._client.node_db_manager.bundled_node_config()
             await config.update_resume_key(f"PyLav/{self._client.lib_version}-{self._client.bot_id}")
